@@ -1,8 +1,20 @@
 #' Create a new tidyplot
 #'
 #' @param data A tidy `data.frame` to use for plotting.
-#' @param ... Mappings for the `x` axis, `y` axis and `color`, see examples. Additional argument are passed to `ggplot2::aes()`.
-#' @inherit common_arguments
+#' @param width Width of the plot area. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `50`.
+#' @param height Height of the plot area. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `50`.
+#' @param unit Unit of the plot area width and height. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `"mm"`.
+#' @param dodge_width For adjusting the distance between grouped objects.
+#' The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `0.8` for plots with
+#' at least one discrete axis and to `0` for plots with two continuous axes.
+#' @param my_style Styling function to apply to the plot. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which default to no additional styling.
+#' @param ... Mappings for the `x` axis, `y` axis and `color`, see examples.
+#' Additional argument are passed to `ggplot2::aes()`.
 #'
 #' @examples
 #' study |>
@@ -16,7 +28,7 @@
 #' # Change plot area size
 #' study |>
 #'   tidyplot(x = treatment, y = score, color = treatment,
-#'     width = 35, height = 35) |>
+#'     width = 25, height = 25) |>
 #'   add_data_points_beeswarm()
 #'
 #' # Change dodge_width
@@ -25,7 +37,12 @@
 #'   add_mean_bar()
 #'
 #' @export
-tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
+tidyplot <- function(data, ...,
+                     width = NULL,
+                     height = NULL,
+                     unit = NULL,
+                     dodge_width = NULL,
+                     my_style = NULL) {
   mapping <- ggplot2::aes(...)
 
   # Add .single_color column to data if `colour` and `fill` mappings are missing
@@ -47,6 +64,10 @@ tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
 
   plot$tidyplot$history <- c("tidyplot")
 
+  plot$tidyplot$width <- width %||% getOption("tidyplots.width") %||% 50
+  plot$tidyplot$height <- height %||% getOption("tidyplots.height") %||% 50
+  plot$tidyplot$unit <- unit %||% getOption("tidyplots.unit") %||% "mm"
+
   plot$tidyplot$padding_x <- c(0.05, 0.05)
   plot$tidyplot$padding_y <- c(0.05, 0.05)
 
@@ -59,7 +80,7 @@ tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
   } else {
     dodge_width_heuristic <- 0
   }
-  dodge_width <- dodge_width %||% dodge_width_heuristic
+  dodge_width <- dodge_width %||% getOption("tidyplots.dodge_width") %||% dodge_width_heuristic
   plot$tidyplot$dodge_width <- dodge_width
 
   plot$tidyplot$named_colors <- NULL
@@ -69,19 +90,79 @@ tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
     adjust_x_axis() |>
     adjust_y_axis() |>
     adjust_colors() |>
-    adjust_size(width = width, height = height)
+    adjust_size()
+
+  my_style <- my_style %||% getOption("tidyplots.my_style")
+  if (!is.null(my_style)) {
+    plot <- plot |> my_style()
+  }
 
   if (single_color_plot)
-    plot <- plot |> remove_legend()
+    plot <- plot +
+    ggplot2::guides(colour = "none", fill = "none")
 
   plot
 }
 
 
+#' Tidyplots options
+#'
+#' Control the settings for formatting tidyplots globally.
+#'
+#' @inheritParams tidyplot
+#' @return The old options invisibly
+#'
+#' @examples
+#'
+#' # Define custom style
+#' my_style <- function(x) x |>
+#'   adjust_colors(colors_discrete_candy) |>
+#'   adjust_font(family = "mono")
+#'
+#' # Set tidyplots options
+#' tidyplots_options(
+#'   width = 3,
+#'   height = 4,
+#'   unit = "cm",
+#'   dodge_width = 1,
+#'   my_style = my_style
+#'   )
+#'
+#' # Plot
+#' study |>
+#'   tidyplot(x = group, y = score, color = dose) |>
+#'   add_mean_bar()
+#'
+#' # Reset tidyplots options
+#' tidyplots_options()
+#'
+#' # Same plot
+#' study |>
+#'   tidyplot(x = group, y = score, color = dose) |>
+#'   add_mean_bar()
+#'
+#' @export
+tidyplots_options <- function(
+  width = NULL,
+  height = NULL,
+  unit = NULL,
+  dodge_width = NULL,
+  my_style = NULL
+) {
+  opts <- options(
+    tidyplots.width = width,
+    tidyplots.height = height,
+    tidyplots.unit = unit,
+    tidyplots.dodge_width = dodge_width,
+    tidyplots.my_style = my_style
+  )
+  invisible(opts)
+}
+
+
 #' Split plot into multiple subplots
 #' @param by Variable that should be used for splitting.
 #' @param ncol,nrow The number of columns and rows per page.
-#' @param unit Unit of length. Defaults to `"mm"`.
 #' @inheritParams patchwork::wrap_plots
 #' @inherit common_arguments
 #'
@@ -90,13 +171,15 @@ tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
 #' energy |>
 #'   dplyr::filter(year %in% c(2005, 2010, 2015, 2020)) |>
 #'   tidyplot(y = energy, color = energy_source) |>
-#'   add_donut()
+#'   add_donut() |>
+#'   adjust_size(width = 25, height = 25)
 #'
 #' # Split by year
 #' energy |>
 #'   dplyr::filter(year %in% c(2005, 2010, 2015, 2020)) |>
 #'   tidyplot(y = energy, color = energy_source) |>
 #'   add_donut() |>
+#'   adjust_size(width = 25, height = 25) |>
 #'   split_plot(by = year)
 #'
 #' # Change dimensions of subplots
@@ -104,23 +187,31 @@ tidyplot <- function(data, ..., width = 50, height = 50, dodge_width = NULL) {
 #'   dplyr::filter(year %in% c(2005, 2010, 2015, 2020)) |>
 #'   tidyplot(y = energy, color = energy_source) |>
 #'   add_donut() |>
-#'   split_plot(by = year, widths = 15, heights = 15)
+#'   adjust_size(width = 15, height = 15) |>
+#'   split_plot(by = year)
 #'
 #' # Spread plots across multiple pages
 #' energy |>
 #'   dplyr::filter(year %in% c(2005, 2010, 2015, 2020)) |>
 #'   tidyplot(y = energy, color = energy_source) |>
 #'   add_donut() |>
+#'   adjust_size(width = 25, height = 25) |>
 #'   split_plot(by = year, ncol = 2, nrow = 1)
 #'
 #' @export
 split_plot <- function(plot, by, ncol = NULL, nrow = NULL, byrow = NULL,
-                       widths = 30, heights = 25, guides = "collect",
-                       tag_level = NULL, design = NULL, unit = "mm") {
+                       guides = "collect", tag_level = NULL, design = NULL) {
   plot <- check_tidyplot(plot)
   if(missing(by))
     cli::cli_abort("Argument {.arg by} missing without default.")
 
+  widths <- plot$tidyplot$width
+  heights <- plot$tidyplot$height
+  unit <- plot$tidyplot$unit
+
+  if (!is.na(widths)) widths <- ggplot2::unit(widths, unit)
+  if (!is.na(heights)) heights <- ggplot2::unit(heights, unit)
+
   # free plot dimensions
   plot <-
     plot |>
@@ -137,13 +228,6 @@ split_plot <- function(plot, by, ncol = NULL, nrow = NULL, byrow = NULL,
            plot %+% data + ggplot2::ggtitle(facet_title)
          })
 
-  if (!is.na(widths)) widths <- ggplot2::unit(widths, unit)
-  if (!is.na(heights)) heights <- ggplot2::unit(heights, unit)
-
-  # if (!ggplot2::is.ggplot(plots) && !all(purrr::map_lgl(plots, ggplot2::is.ggplot)))
-  #   cli::cli_abort("{.arg plots} must be a single plot or a list of plots.")
-  # if (ggplot2::is.ggplot(plots)) plots <- list(plots)
-
   if (is.numeric(ncol) && is.numeric(nrow)) {
     plots_per_page <- nrow * ncol
   } else {
@@ -255,6 +339,7 @@ view_plot <- function(plot, data = all_rows(), title = ggplot2::waiver(), ...) {
 #'   dplyr::slice_head(n = 160) |>
 #'   tidyplot(group, expression, color = sample_type) |>
 #'   add_data_points() |>
+#'   adjust_size(width = 30, height = 25) |>
 #'   split_plot(by = external_gene_name, nrow = 2, ncol = 2) |>
 #'   save_plot("multipage_plot.pdf")
 #'
@@ -263,6 +348,7 @@ view_plot <- function(plot, data = all_rows(), title = ggplot2::waiver(), ...) {
 #'   dplyr::slice_head(n = 160) |>
 #'   tidyplot(group, expression, color = sample_type) |>
 #'   add_data_points() |>
+#'   adjust_size(width = 30, height = 25) |>
 #'   split_plot(by = external_gene_name, nrow = 2, ncol = 2) |>
 #'   save_plot("plot.pdf", multiple_files = TRUE)
 #'
